summaryrefslogtreecommitdiff
path: root/gtk2_ardour/new_session_dialog.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2010-04-15 14:41:38 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2010-04-15 14:41:38 +0000
commit5565078136e72c6c098fc4b4b688f6c1af58d069 (patch)
treedb7aa276be3e7b08480eda6bc1e1e5aee40c8af4 /gtk2_ardour/new_session_dialog.cc
parent1d1de9b669a141954a252a1d0173ddc6348cba9c (diff)
remove a bunch of explicit uses of '/' as a directory separator; use Glib::build_filename() to construct more paths rather than doing it "by hand"; fixup small logic mistake (which had no actual consequences) in export track marker dialog
git-svn-id: svn://localhost/ardour2/branches/2.0-ongoing@6909 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/new_session_dialog.cc')
-rw-r--r--gtk2_ardour/new_session_dialog.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/gtk2_ardour/new_session_dialog.cc b/gtk2_ardour/new_session_dialog.cc
index d7f7539185..98ff6a2586 100644
--- a/gtk2_ardour/new_session_dialog.cc
+++ b/gtk2_ardour/new_session_dialog.cc
@@ -618,8 +618,8 @@ NewSessionDialog::set_session_folder(const Glib::ustring& dir)
std::string
NewSessionDialog::session_name() const
{
- std::string str = Glib::filename_from_utf8(m_open_filechooser->get_filename());
- std::string::size_type position = str.find_last_of ('/');
+ std::string str = Glib::filename_from_utf8 (m_open_filechooser->get_filename());
+ std::string::size_type position = str.find_last_of (G_DIR_SEPARATOR);
str = str.substr (position+1);
position = str.find_last_of ('.');
str = str.substr (0, position);
@@ -1073,9 +1073,9 @@ NewSessionDialog::reset_recent()
std::vector<const gchar*> item;
std::string fullpath = *(*i);
- /* remove any trailing / */
+ /* remove any trailing separator */
- if (fullpath[fullpath.length()-1] == '/') {
+ if (fullpath[fullpath.length()-1] == G_DIR_SEPARATOR) {
fullpath = fullpath.substr (0, fullpath.length()-1);
}